==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databricks/kotlin/inputs/WorkspaceCustomStringParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databricks.kotlin.inputs

import com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Value.
 * @property value The value which should be used for this field.
 */
public data class WorkspaceCustomStringParameterArgs(
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs> {
    override fun toJava(): com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs =
        com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs.builder()
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceCustomStringParameterArgs].
 */
@PulumiTagMarker
public class WorkspaceCustomStringParameterArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value The value which should be used for this field.
     */
    @JvmName("kitvjfrkscfxswwd")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The value which should be used for this field.
     */
    @JvmName("gqvirqivrslbmmeo")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): WorkspaceCustomStringParameterArgs = WorkspaceCustomStringParameterArgs(
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databricks/kotlin/inputs/WorkspaceCustomStringParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databricks.kotlin.inputs

import com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Value.
 * @property value The value which should be used for this field.
 */
public data class WorkspaceCustomStringParameterArgs(
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs> {
    override fun toJava(): com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs =
        com.pulumi.azurenative.databricks.inputs.WorkspaceCustomStringParameterArgs.builder()
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceCustomStringParameterArgs].
 */
@PulumiTagMarker
public class WorkspaceCustomStringParameterArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value The value which should be used for this field.
     */
    @JvmName("uxvakjophxblnwvr")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The value which should be used for this field.
     */
    @JvmName("dyodypcqkvqaaslr")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): WorkspaceCustomStringParameterArgs = WorkspaceCustomStringParameterArgs(
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
